import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
/*
 * @(#)GrafikaKalkulacky
 *
 * Třída zobrazí okno kalkulačky a obsluhuje události v okně (stisky tlačítka) - pro výkonné funkce se
 * volají příslušné metody ze třídy Kalkulator
 *
 * @author     Luboš Pavlíček
 * @version    26. ledna 2005
 */
public class GrafikaKalkulacky {

    private JFrame okno;
    private Kalkulator kalk;
    private JTextField display;
    private JLabel info;
    private boolean infoBarevne;
    private String [] popiskyTlacitek = { 
        "7","8","9","/","C",
        "4","5","6","*","x^2",
        "1","2","3","-","x^3",
        "?","0","+/-","+","=" };

    /**
     * Vnitřní třída, která obsahuje obsluhu stisknutí tlačítek. Potomek ActionListeneru, přiřazuje
     * se k tlačítkům v konstruktoru třídy GrafikaKalkulacky
     */    
    private class ObsluhaTlacitka implements ActionListener{
        /**
         * metoda actionPerformed se volá automaticky při stisknutí tlačítka
         * obsluhuje všechny tlačítka kalkulačky
         */
        public void actionPerformed(ActionEvent event){
            String prikaz = event.getActionCommand();   
            if (prikaz.equals("+")) {
                kalk.plus();
            }
            if (prikaz.equals("-")) {
                kalk.minus();
            }
            if (prikaz.equals("=")) {
                kalk.rovnaSe();
            }
            if (prikaz.equals("C")) {
                kalk.vymaz();
            }
            if (prikaz.equals("?")) {
                showInfo();
            }
            if (prikaz.equals("0") ||
                prikaz.equals("1") ||
                prikaz.equals("2") ||
                prikaz.equals("3") ||
                prikaz.equals("4") ||
                prikaz.equals("5") ||
                prikaz.equals("6") ||
                prikaz.equals("7") ||
                prikaz.equals("8") ||
                prikaz.equals("9")) {
                int hodnota=Integer.parseInt(prikaz);
                kalk.cislice(hodnota);
            }
            if (prikaz.equals("/")) {
                kalk.deleni();
            }
            if (prikaz.equals("*")) {
                kalk.nasobeni();
            }
            if (prikaz.equals("+/-")) {
                kalk.znamenko();
            }
            if (prikaz.equals("x^2")) {
                kalk.mocnina();
            }
            if (prikaz.equals("x^3")) {
                kalk.tretiMocnina();
            }
            
            redisplay();
        }
    }
     
    /**
     * Konstruktor pro objekty tridy GrafikaKalkulacky
     */
    public GrafikaKalkulacky(Kalkulator kalk) {
    
        JButton[] tlacitka = new JButton [popiskyTlacitek.length];
    
        JPanel panelTlacitek = new JPanel();
        JPanel hlavniPanel = new JPanel();
        info = new JLabel();
        display = new JTextField(12);
        
        display.setHorizontalAlignment(JTextField.RIGHT);
        display.setEditable(false);
        display.setBackground(Color.WHITE);
        JPanel panelDisplay = new JPanel();

        okno=new JFrame();
        this.kalk=kalk;

        Color barvaCislic=new Color(144,224,144);
        Color barvaOperaci=new Color(96,208,96);
        Color barvaDisplay=Color.WHITE;
        Color barvaPozadi =new Color(192,244,192);
        display.setBackground(barvaDisplay);
        
        javax.swing.border.Border ohraniceni = BorderFactory.createRaisedBevelBorder();
        
        okno.getContentPane().setBackground(barvaPozadi);
        panelTlacitek.setBackground(barvaPozadi);
        hlavniPanel.setBackground(barvaPozadi);
        panelDisplay.setBackground(barvaPozadi);

        okno.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        panelTlacitek.setLayout(new GridLayout(4,5));
        for (int i=0; i<tlacitka.length;i++){
            tlacitka[i] = new JButton(popiskyTlacitek[i]);
            panelTlacitek.add(tlacitka[i]);
            tlacitka[i].addActionListener(new ObsluhaTlacitka());
            if (isCislice(popiskyTlacitek[i])) { 
                tlacitka[i].setBackground(barvaCislic);
            }
            else {
                tlacitka[i].setBackground(barvaOperaci);
            }
            tlacitka[i].setFocusPainted(false);
            tlacitka[i].setBorder(ohraniceni);
         }
     
        okno.getContentPane().add(panelTlacitek);
      
       panelDisplay.add(display);
       okno.getContentPane().add(panelDisplay,BorderLayout.NORTH);
       okno.getContentPane().add(info,BorderLayout.SOUTH);
       okno.setSize(240,200);
       okno.setTitle("Celočíselná kalkulačka");
       info.setText(".....");
       redisplay();
    }

    /**
     * Metoda zobrazí hodnotu na displayi kalkulacky.
     */
    private void redisplay() {
        display.setText("" + kalk.getHodnotaKZobrazeni());
    };
    
    /**
     * Metoda zobrazí informace o autorovi a o verzi
     */    
    private void showInfo() {
        info.setText(kalk.getAutor()+" "+kalk.getVerze());
        if (infoBarevne) {
            info.setForeground(Color.GREEN);
            infoBarevne=false;
        }
        else {
            info.setForeground(Color.BLACK);
            infoBarevne=true;
        }

    };

    /**
     * Metoda zobrazí vytvořené okno na obrazovce.
     */
    public void setVisible () {
        okno.setVisible(true);
    }

    /**
     * metoda zjistuje, zda na tlacitku je cislice
     * 
     * @return true, pokud je na tlacitku cislice 0 až 9
     */
    private boolean isCislice(String popisek) {
        return (popisek.length()==1) && (popisek.charAt(0) >= '0') && (popisek.charAt(0) <='9');
    }
    
}
