import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
/*
 * @(#)GrafikaKalkulacky
 *
 * Třída zobrazí okno kalkulačky a obsluhuje události v okně (stisky tlačítka) - pro výkonné funkce se
 * volají příslušné metody ze třídy Kalkulator
 *
 * @author     Luboš Pavlíček
 * @version    26. ledna 2005
 */
public class GrafikaKalkulacky {
    private JFrame okno;
    private Kalkulator kalk;
    private JTextField display;
    private JLabel info;
    private boolean infoBarevne;
    private String [] popiskyTlacitek = { 
        "A","B","C","D","E",
        "7","8","9","cl","F",
        "4","5","6","+","MC",
        "1","2","3","-","MR",
        "?","0","+/-","=","M+" };
    private String [] popiskyTlacitek2 = { "Dec","Hex","Oct","Bin"};
    private JButton [] ciselnaTlacitka = new JButton[16];
   
    /**
     * Vnitřní třída, která obsahuje obsluhu stisknutí tlačítek. Potomek ActionListeneru, přiřazuje
     * se k tlačítkům v konstruktoru třídy GrafikaKalkulacky
     */   
    private class ObsluhaTlacitka implements ActionListener{
        /**
         * metoda actionPerformed se volá automaticky při stisknutí tlačítka
         * obsluhuje všechny tlačítka kalkulačky
         */        
        public void actionPerformed(ActionEvent event){
            String prikaz = event.getActionCommand();   
            if (prikaz.equals("+")) {
                kalk.plus();
            }
            if (prikaz.equals("-")) {
                kalk.minus();
            }
            if (prikaz.equals("=")) {
                kalk.rovnaSe();
            }
            if (prikaz.equals("cl")) {
                kalk.vymaz();
            }
            if (prikaz.equals("MR")) {
                kalk.mRestore();
            }
            if (prikaz.equals("MC")) {
                kalk.mClear();
            }
            if (prikaz.equals("M+")) {
                kalk.mPlus();
            }
            if (prikaz.equals("+/-")) {
                kalk.znamenko();
            }
            if (prikaz.equals("?")) {
                showInfo();
            }
            if (prikaz.equals("0") ||
                prikaz.equals("1") ||
                prikaz.equals("2") ||
                prikaz.equals("3") ||
                prikaz.equals("4") ||
                prikaz.equals("5") ||
                prikaz.equals("6") ||
                prikaz.equals("7") ||
                prikaz.equals("8") ||
                prikaz.equals("9") ||
                prikaz.equals("A") ||
                prikaz.equals("B") ||
                prikaz.equals("C") ||
                prikaz.equals("D") ||
                prikaz.equals("E") ||
                prikaz.equals("F")) {
                int hodnota=Integer.parseInt(prikaz,16);
                kalk.cislice(hodnota);
            }
            if (prikaz.equals("Dec")) {
                kalk.desitkova();
                aktivaceKlaves(10);
            }
            if (prikaz.equals("Hex")) {
                kalk.sestnactkova();
                aktivaceKlaves(16);
            }
            if (prikaz.equals("Oct")) {
                kalk.osmickova();
                aktivaceKlaves(8);
            }
            if (prikaz.equals("Bin")) {
                kalk.dvojkova();
                aktivaceKlaves(2);
            }
            
            redisplay();
        }
    }
     
    /**
     * Konstruktor pro objekty tridy GrafikaKalkulacky
     */
    public GrafikaKalkulacky(Kalkulator kalk) 
    {
    
        JButton[] tlacitka = new JButton [popiskyTlacitek.length];
        JButton[] tlacitka2 = new JButton [ popiskyTlacitek2.length];
    
        JPanel panelTlacitek = new JPanel();
        JPanel panelTlacitek2 = new JPanel();
        JPanel hlavniPanel = new JPanel();
        info = new JLabel();
        display = new JTextField(12);
        
        display.setHorizontalAlignment(JTextField.RIGHT);
        display.setEditable(false);
        display.setBackground(Color.WHITE);
        JPanel panelDisplay = new JPanel();

        okno=new JFrame();
        this.kalk=kalk;

        okno.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        panelTlacitek.setLayout(new GridLayout(5,5));
        for (int i=0; i<tlacitka.length;i++){
            tlacitka[i] = new JButton(popiskyTlacitek[i]);
            panelTlacitek.add(tlacitka[i]);
            tlacitka[i].addActionListener(new ObsluhaTlacitka());
            tlacitka[i].setMargin(new Insets(2,6,2,6));
            try {
                int poradi=Integer.parseInt(popiskyTlacitek[i],16);
                ciselnaTlacitka[poradi]=tlacitka[i];
            }
            catch (NumberFormatException exc) {
            }
         }
         panelTlacitek2.setLayout(new GridLayout(4,1));
         for (int i=0; i< tlacitka2.length; i++) {
             tlacitka2[i] = new JButton(popiskyTlacitek2[i]);
             panelTlacitek2.add(tlacitka2[i]);
             tlacitka2[i].addActionListener(new ObsluhaTlacitka());
             tlacitka2[i].setMargin(new Insets(2,10,2,10));
         }
         
         hlavniPanel.add(panelTlacitek);
         hlavniPanel.add(panelTlacitek2);
     
        okno.getContentPane().add(hlavniPanel);
      
       panelDisplay.add(display);
       okno.getContentPane().add(panelDisplay,BorderLayout.NORTH);
       okno.getContentPane().add(info,BorderLayout.SOUTH);
       okno.setSize(255,215);
       okno.setTitle("Kalkulacka s čís. soustavami");
       info.setText(".....");
       aktivaceKlaves(10);
       redisplay();
    }
    
    /**
     * Metoda zobrazí hodnotu na displayi kalkulacky.
     */    
    private void redisplay() {
        display.setText(kalk.getHodnotaKZobrazeni());
    };
    
    /**
     * Metoda zobrazí informace o autorovi a o verzi
     */    
    private void showInfo() {
        info.setText(kalk.getAutor()+" "+kalk.getVerze());
        if (infoBarevne) {
            info.setForeground(Color.BLUE);
            infoBarevne=false;
        }
        else {
            info.setForeground(Color.BLACK);
            infoBarevne=true;
        }
    };
    /**
     * Metoda zobrazí vytvořené okno na obrazovce.
     */
    public void setVisible () {
        okno.setVisible(true);
    }
    
    private void aktivaceKlaves(int pocet) {
        for (int i=0; i< ciselnaTlacitka.length; i++) {
            if (i < pocet) {
                ciselnaTlacitka[i].setEnabled(true);
            }
            else {
                ciselnaTlacitka[i].setEnabled(false);
            }
        }
    }
    
}
