/**
 *
 * Toto rozhraní definuje metody kalkulátoru. Rozhraní má tři skupiny metod:
 * a) pomocí metody getHodnotaKZobrazeni grafická třída zjištuje co má zobrazit na
 *    displayi,
 * b) metody cislice, plus, minus, rovnaSe, vymaz, nasobeni, deleni, znamenko, vymazCisla a modulo se volají
 *    při stisknutí příslušné klávesy na kalkulačce,
 * c) metody getAutor a getVerze jsou informační
 *
 * @author     jmeno autora
 * @version    cislo verze, datum
 */
public interface Kalkulator 
{

    /**
     * Metoda vrací hodnotu, která se má zobrazit na displayi kalkulacky. Tato metoda
     * se obvykle volá po zavolání metody odpovídající stisku tlačítka.
     * 
     * @return   hodnota k zobrazení - reálná i imaginární část
     */
 
    public String getHodnotaKZobrazeni();

    /**
     * metoda se volá při stisknutí tlačítka s číslicí na kalkulačce. Parametrem
     * je hodnota na stisknuté klávese.
     * 
     * @param hodnota    hodnota na stisknutém tlačítku, hodnota je v rozsahu
     *                   od 0 do 9
     */
    public void cislice(int hodnota);

    /**
     * metoda se volá při stisknutí tlačítka "+" (plus) na kalkulačce
     */
    public void plus();

    /**
     * metoda se volá při stisknutí tlačítka "-" (minus) na kalkulačce
     */
    public void minus();

    /**
     * metoda se volá při stisknutí tlačítka "=" (rovná se) na kalkulačce
     */
    public void rovnaSe();
    
    /**
     * metoda se volá při stisknutí tlačítka "C" (clear) na kalkulačce
     */
    public void vymaz();
    
    /**
     * metoda se volá při stisknutí tlačítka / - dělení
     */
    public void deleni();
    
    /**
     * metoda se volá při stisknutí tlačítka * - násobení
     */
    public void nasobeni();
    
    /**
     * metoda se volá při stisknutí tlačítka i - vkládání imaginární části
     * komplexního čísla
     */
    public void imaginarni();
    

    /**
     * metoda se volá při stisknutí tlačítka CE - vymazaní/vynulování posledního vkládáného čísla
     * (dříve navkládané operace by se měly uchovat)
     */
    public void vymazCisla();

    /**
     * metoda vrací jméno autora, např. "autor: Jan Novák"
     * 
     * @return   řetězec se jménem autora
     */    
    public String getAutor();
    
    /**
     * metoda vrací označení verze, např. "verze 1.0.3"
     * 
     * @return   řetězec s verzí programu
     */
    public String getVerze();
    
}
