/**
 * Třída na převod čísel zapsaných pomocí římských číslic na čísla (int) a obráceně,
 * tj. na převode čísel na čísla zapsaná pomocí římských číslic.
 * Přípustná jsou pouze čísla v rozsahu 1 až 3999, používá se klasický zápis,
 * který neumožňuje zapsat čtyři stejné znaky za sebou.
 */

public class Roman {

    /**
     * Pomocná vnitřní třída pro vytvoření pomocného pole, s jehož pomocí
     * se provádí převody. Vzhledem k tomu, že třída poskytuje statické metody,
     * tak i tato pomocná třída je statická.
     */
    private static class Dvojice {
        private int arab;
        private String roman;
        private int opakovat;
        private int preskocit;
        Dvojice (int arab, String roman, int opakovat, int preskocit) {
            this.arab=arab;
            this.roman=roman;
            this.opakovat=opakovat;
            this.preskocit=preskocit;
        }
    }

    /**
     * statické pomocné pole
     */
    private static Dvojice tabulka [] = {
        new Dvojice (1000, "M", 3, 0 ),
        new Dvojice (900, "CM", 1, 4 ),
        new Dvojice (500, "D" , 1, 2 ),
        new Dvojice (400, "CD", 1, 2 ),
        new Dvojice (100, "C" , 3, 0 ),
        new Dvojice ( 90, "XC", 1, 4 ),
        new Dvojice ( 50, "L" , 1, 2 ),
        new Dvojice ( 40, "XL", 1, 2 ),
        new Dvojice ( 10, "X" , 3, 0 ),
        new Dvojice (  9, "IX", 1, 4 ),
        new Dvojice (  5, "V" , 1, 2 ),
        new Dvojice (  4, "IV", 1, 2 ),
        new Dvojice (  1, "I" , 3, 0 )
    };
   
    /**
     * Metoda pro převod čísel zapsaných pomocí římských číslic. Římské číslo
     * musí odpovídat klasickým pravidlům pro jejich zápis, písmena I, X, C a M lze
     * opakovat maximálně 3. Číslo bude v rozsahu 1 až 3999.
     * 
     * @param   rimskeCislo    vstupní číslo zapsané pomocí římských číslic
     * @return     výsledné číslo
     * @exception NumberFormatException - pokud vstupní řetězec neodpovídá
     *              pravidlům pro zápis římského čísla, vznikne tato výjimka
     */
    public static int fromRoman  (String rimskeCislo) throws NumberFormatException {
        String vstup=rimskeCislo;
        int vysl = 0;
        int indexOd = 0;
        int minulyZnak = 0;
        int opakovani = 0;
        if (vstup.length()==0) {
            throw new NumberFormatException("musí být zadán aspoň jeden znak");
        }
        postupnyPruchod:
        while (vstup.length() > 0) {
            for (int i=indexOd; i< tabulka.length; i++) {
                if (vstup.startsWith(tabulka[i].roman)) {
                    vysl=vysl+tabulka[i].arab;
                    vstup=vstup.substring(tabulka[i].roman.length());
                    if (minulyZnak == i) {
                        opakovani++;
                        if (tabulka[i].opakovat < opakovani) {
                            throw new NumberFormatException(rimskeCislo+ " není římské číslo (opakovani)");
                        }
                    }
                    else {
                        opakovani=1;
                    }
                    minulyZnak=i;
                    indexOd=i + tabulka[i].preskocit;
                    continue postupnyPruchod;
                }
            }
            throw new NumberFormatException(rimskeCislo + " není římské číslo");
        }
        return vysl;
   }

    /**
     * Metoda převádí číslo do zápisu pomocí římských číslic. 
     * 
     * @param   prevadeneCislo    číslo, které se má převádět. Musí být v rozsahu 1 až 3999
     * @return     řetězec s římským zápisem čísla,
     * @exception IllegalArgumentException  tato výjimka vznikne, pokud vstupní
     *                                      hodnota je mimo rozsah 1 až 3999
     */
    public static String toRoman  (int prevadeneCislo) throws IllegalArgumentException {
        if ((prevadeneCislo > 3999) || (prevadeneCislo <= 0)) {
            throw new IllegalArgumentException();
        }
        else {
            int cislo = prevadeneCislo;
            String vysl="";
            while (cislo > 0) {
                for (int j=0; j < tabulka.length; j++) {
                    if (cislo >= tabulka[j].arab) {
                        vysl=vysl+tabulka[j].roman;
                        cislo=cislo-tabulka[j].arab;
                        break;
                    }
                }
            }
            return vysl;
        }
    }
}
