import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
/*
 * @(#)GrafikaKalkulacky
 *
 * Třída zobrazí okno kalkulačky a obsluhuje události v okně (stisky tlačítka) - pro výkonné funkce se
 * volají příslušné metody ze třídy Kalkulator
 *
 * @author     Luboš Pavlíček
 * @version    26. ledna 2005
 */
public class GrafikaKalkulacky {

    private JFrame okno;
    private Kalkulator kalk;
    private JTextField display;
    private JLabel info;
    private boolean infoBarevne;
    private String [] popiskyTlacitek = { 
        "I","V","/","cl",
        "X","L","*","ce",
        "C","D","-","Mod",
        "M","?","+","=" };

    /**
     * Vnitřní třída, která obsahuje obsluhu stisknutí tlačítek. Potomek ActionListeneru, přiřazuje
     * se k tlačítkům v konstruktoru třídy GrafikaKalkulacky
     */    
    private class ObsluhaTlacitka implements ActionListener{
        /**
         * metoda actionPerformed se volá automaticky při stisknutí tlačítka
         * obsluhuje všechny tlačítka kalkulačky
         */
        public void actionPerformed(ActionEvent event){
            String prikaz = event.getActionCommand();   
            if (prikaz.equals("+")) {
                kalk.plus();
            }
            if (prikaz.equals("-")) {
                kalk.minus();
            }
            if (prikaz.equals("=")) {
                kalk.rovnaSe();
            }
            if (prikaz.equals("cl")) {
                kalk.vymaz();
            }
            if (prikaz.equals("?")) {
                showInfo();
            }
            if (prikaz.equals("I") ||
                prikaz.equals("V") ||
                prikaz.equals("X") ||
                prikaz.equals("L") ||
                prikaz.equals("C") ||
                prikaz.equals("D") ||
                prikaz.equals("M")) {
                kalk.cislice(prikaz.charAt(0));
            }
            if (prikaz.equals("/")) {
                kalk.deleni();
            }
            if (prikaz.equals("*")) {
                kalk.nasobeni();
            }
            if (prikaz.equals("Mod")) {
                kalk.modulo();
            }
            if (prikaz.equals("ce")) {
                kalk.vymazCisla();
            }
            
            redisplay();
        }
    }
     
    /**
     * Konstruktor pro objekty tridy GrafikaKalkulacky
     */
    public GrafikaKalkulacky(Kalkulator kalk) {
    
        JButton[] tlacitka = new JButton [popiskyTlacitek.length];
    
        JPanel panelTlacitek = new JPanel();
        info = new JLabel();
        display = new JTextField(12);
        
        display.setHorizontalAlignment(JTextField.RIGHT);
        display.setEditable(false);
        display.setBackground(Color.WHITE);
        JPanel panelDisplay = new JPanel();

        okno=new JFrame();
        this.kalk=kalk;

        okno.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        panelTlacitek.setLayout(new GridLayout(4,5));
        for (int i=0; i<tlacitka.length;i++){
            tlacitka[i] = new JButton(popiskyTlacitek[i]);
            panelTlacitek.add(tlacitka[i]);
            tlacitka[i].addActionListener(new ObsluhaTlacitka());
            tlacitka[i].setMargin(new Insets(2,6,2,6));
            //System.out.println(popiskyTlacitek[i]+": "+tlacitka[i].getMargin());
         }
     
        okno.getContentPane().add(panelTlacitek);
      
       panelDisplay.add(display);
       okno.getContentPane().add(panelDisplay,BorderLayout.NORTH);
       okno.getContentPane().add(info,BorderLayout.SOUTH);
       okno.setSize(240,200);
       okno.setTitle("Celočíselná kalkulačka");
       info.setText(".....");
       redisplay();
    }

    /**
     * Metoda zobrazí hodnotu na displayi kalkulacky.
     */
    private void redisplay() {
        display.setText("" + kalk.getHodnotaKZobrazeni());
    };
    
    /**
     * Metoda zobrazí informace o autorovi a o verzi
     */    
    private void showInfo() {
        info.setText(kalk.getAutor()+" "+kalk.getVerze());
        if (infoBarevne) {
            info.setForeground(Color.BLUE);
            infoBarevne=false;
        }
        else {
            info.setForeground(Color.BLACK);
            infoBarevne=true;
        }
        
    };

    /**
     * Metoda zobrazí vytvořené okno na obrazovce.
     */
    public void setVisible () {
        okno.setVisible(true);
    }
    
}
