
/**
 * Testovaci trida RomanTest
 *
 * @author     Luboš Pavlíček
 * @version    2.0, 16. října 2006
 */
public class RomanTest extends junit.framework.TestCase
{
    /**
     * vnitřní třída, která se používá pro vytvoření dvojic 
     * číslo arabskými číslicemi - číslo římskými číslicemi
     */
    private class Dvojice {
        private int arab;
        private String roman;
        Dvojice (int arab, String roman) {
            this.arab=arab;
            this.roman=roman;
        }
   }

   private Dvojice knownValues [] =  {
      new Dvojice(1,"I"),
      new Dvojice(2,"II"),
      new Dvojice(3,"III"),
      new Dvojice(4,"IV"),
      new Dvojice(5,"V"),
      new Dvojice(6,"VI"),
      new Dvojice(7,"VII"),
      new Dvojice(8,"VIII"),
      new Dvojice(9,"IX"),
      new Dvojice(10,"X"),
      new Dvojice(50,"L"),
      new Dvojice(100,"C"),
      new Dvojice(500,"D"),
      new Dvojice(1000,"M"),
      new Dvojice(31,"XXXI"),
      new Dvojice(148,"CXLVIII"),
      new Dvojice(294,"CCXCIV"),
      new Dvojice(312,"CCCXII"),
      new Dvojice(421,"CDXXI"),
      new Dvojice(528,"DXXVIII"),
      new Dvojice(621,"DCXXI"),
      new Dvojice(782,"DCCLXXXII"),
      new Dvojice(870,"DCCCLXX"),
      new Dvojice(941,"CMXLI"),
      new Dvojice(1043,"MXLIII"),
      new Dvojice(1110,"MCX"),
      new Dvojice(1226,"MCCXXVI"),
      new Dvojice(1301,"MCCCI"),
      new Dvojice(1485,"MCDLXXXV"),
      new Dvojice(1509,"MDIX"),
      new Dvojice(1607,"MDCVII"),
      new Dvojice(2499,"MMCDXCIX"),
      new Dvojice(2574,"MMDLXXIV"),
      new Dvojice(2646,"MMDCXLVI"),
      new Dvojice(2723,"MMDCCXXIII"),
      new Dvojice(2892,"MMDCCCXCII"),
      new Dvojice(2975,"MMCMLXXV"),
      new Dvojice(3051,"MMMLI"),
      new Dvojice(3313,"MMMCCCXIII"),
      new Dvojice(3408,"MMMCDVIII"),
      new Dvojice(3501,"MMMDI"),
      new Dvojice(3610,"MMMDCX"),
      new Dvojice(3743,"MMMDCCXLIII"),
      new Dvojice(3844,"MMMDCCCXLIV"),
      new Dvojice(3888,"MMMDCCCLXXXVIII"),
      new Dvojice(3940,"MMMCMXL"),
      new Dvojice(3999,"MMMCMXCIX"),
   };

    /**
     * Konstruktor umoznujici spustit definovany test.
     */
    public RomanTest( String nazevTestu )
    {
        super( nazevTestu );
    }


    /**
     * Vytvoreni pripravku (fixture), tj. sady objektu, s nimiz budou vsechny
     * testy pracovat a ktera se proto vytvori pred spustenim kazdeho testu.         
     */
    protected void setUp()
    {
    }


    /**
     * Uklid po testu - tato metoda se spusti po vykonani kazdeho testu.
     */
    protected void tearDown()
    {
    }
    
    /**
     * Testuje se metoda toRoman - zda se správně převádějí čísla arabskými
     * číslicemi na čísla římskými číslicemi. V cyklu se prochází seznam
     * Dvojic vytvořený nahoře.
     */
    public void testToRomanKnownValues () {
        for (int i = 0; i< knownValues.length; i++) {
            String vysl = Roman.toRoman(knownValues[i].arab);
            assertEquals(knownValues[i].roman, vysl);
        }
    }

    /**
     * Testuje se metoda fromRoman - zda se správně převádějí čísla zapsaná
     * římskými číslicemi na čísla zapsaná arabskými číslicemi. V cyklu
     * se prochází seznam Dvojic vytvořený nahoře.
     */
    public void testFromRomanKnownValues () {
        for (int i = 0; i< knownValues.length; i++) {
            int vysl = Roman.fromRoman(knownValues[i].roman);
            assertEquals(knownValues[i].arab, vysl);
        }
    }

    /**
     * testuje se, zda vznikne výjimka v okamžiku, kdy se pokusíme převést na
     * římské číslice čísla, které pomocí nich nelze vyjádřit.
     */
    public void testToRomanException () {
        int badValues [] = { 0, -1, 4000 };
        for (int i = 0; i < badValues.length; i++) {
            try {
                String vysl=Roman.toRoman(badValues[i]);
            }
            catch (IllegalArgumentException e) {
                continue;
            }
            fail("Expected IllegalArgumentException");
        }
    }

    /**
     * Testuje se, zda se správně vyhodí výjimka, pokud se zadají nepřípustné
     * znaky do vstupu římského čísla.
     */
    public void testIllegalCharacters () {
        String badValues [] = { "I ", "i", "a", "mm", "d", "MCi", "", " " };
        for (int i = 0; i < badValues.length; i++) {
            try {
                int vysl=Roman.fromRoman(badValues[i]);
            }
            catch (NumberFormatException e) {
                continue;
            }
            fail("Expected IllegalArgumentException for "+badValues[i]);
        }
    }

    /**
     * Testuje se, zda při převodu z římských čísel se správně detekuje
     * chybné opakování písmen.
     */
    public void testTooManyRepeatedNumerals () {
        String badValues [] = { "MMMM", "VV", "LL", "CCCC", "DD", "IIII" };
        for (int i = 0; i < badValues.length; i++) {
            try {
                int vysl=Roman.fromRoman(badValues[i]);
            }
            catch (NumberFormatException e) {
                continue;
            }
            fail("Expected IllegalArgumentException for "+badValues[i]);
        }
    }

    /**
     * Testuje se, zda se při převodu římských čísel správně testují
     * nepřípustná opakování dvojic římských čísel.
     */
    public void testRepeatedPairs () {
        String badValues [] = { "CMCM", "CDCD", "IVIV", "IXIX", "XLXL" };
        for (int i = 0; i < badValues.length; i++) {
            try {
                int vysl=Roman.fromRoman(badValues[i]);
            }
            catch (NumberFormatException e) {
                continue;
            }
            fail("Expected IllegalArgumentException for "+badValues[i]);
        }
    }
   
    /**
     * Testuje se nepřípustné pořadí římských číslic v čísle.
     */
    public void testMalformedAntecedent () {
        String badValues [] = { "IIMMCC", "VX", "DCM", "CMM", "CMD", "IXIV", "MCMC",
                  "XCX", "IVI", "LM", "LD", "LC" };
        int vysl;
        for (int i = 0; i < badValues.length; i++) {
            try {
                vysl=Roman.fromRoman(badValues[i]);
            }
            catch (NumberFormatException e) {
                continue;
            }
            fail("Expected IllegalArgumentException for "+badValues[i] + " (" +vysl);
        }
    }

    /**
     * testuje se, zda jsou metody reflexivní
     */
    public void testSanity () {
        for (int i=1; i < 4000; i++) {
            int vysl = Roman.fromRoman(Roman.toRoman(i));
            assertEquals(i, vysl);
        }
    }
}
